/*
 * Copyright (C) 2018 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.diagnostic.hprof.util

import com.intellij.ide.util.DelegatingProgressIndicator
import com.intellij.openapi.progress.ProgressIndicator

class PartialProgressIndicator(indicator: ProgressIndicator,
                               private val start: Double,
                               private val duration: Double) : DelegatingProgressIndicator(indicator) {
  private var current: Double = 0.0

  init {
    fraction = 0.0
  }

  override fun start() {
    fraction = 0.0
  }

  override fun stop() {
    fraction = 1.0
  }

  override fun setFraction(fraction: Double) {
    current = fraction
    super.setFraction(start + current * duration)
  }

  override fun getFraction(): Double {
    return current
  }
}